@@ -24,7 +24,6 @@ from oort.shared.constants import OORT_UPLOADER_FOLDER_DETECTION_TICK_SECONDS
 from oort.shared.errors import OortCloudError
 from oort.shared.identity import Identity
 from oort.shared.utils import tail
-from oort.uploader.engine.walker import walk
 
 pass_state = click.make_pass_decorator(State, ensure=True)
 
@@ -139,6 +138,7 @@ def status(state):
 @pass_state
 def start(state):
     start_supervisor_processes(debug=state.debug)
+    get_supervisor_processes_status(debug=state.debug)
 
 
 @main.command(help='Stop Oort processes.')
@@ -146,6 +146,7 @@ def start(state):
 @pass_state
 def stop(state):
     stop_supervisor_processes(debug=state.debug)
+    get_supervisor_processes_status(debug=state.debug)
 
 
 @main.command(help='Stop Oort process and deamon, reconfigure, and restart everything.')
@@ -250,13 +251,18 @@ def telescopes(state, organisation=None):
               help="The Organisation subdomain, if uploading to an organisation.")
 @click.option('-t', '--telescope',
               required=False, nargs=1, type=click.STRING,
-              help="The UUID or the alias of the telescope acquiring data (mandatory for organisation uploads).")
+              help="The UUID or the alias of the telescope acquiring the data (mandatory only for organisation "
+                   "uploads).")
 @click.option('-f', '--force',
               required=False, nargs=1, type=click.BOOL, is_flag=True,
-              help="Force the re-uploading of folder's content, resetting the local Uploads information. Default is False.")
+              help="Force the re-uploading of folder's content, resetting the local Uploads information. Default is "
+                   "False.")
+@click.option('-z', '--zip',
+              required=False, nargs=1, type=click.BOOL, is_flag=True,
+              help="Zip the data files (FITS and XISF) before sending to the cloud. Default is False.")
 @basic_options
 @pass_state
-def upload(state, folder, organisation=None, telescope=None, force=False):
+def upload(state, folder, organisation=None, telescope=None, force=False, zip=False):
     """
     Upload the content of a folder.
 
@@ -267,13 +273,18 @@ def upload(state, folder, organisation=None, telescope=None, force=False):
     every new file created in the folder tree will trigger a sync + upload
     process.
     """
+    click.echo(f"\n{80 * '*'}")
+    click.echo(" • DIRECT MODE: command will not return until it has completed the upload of folder's files.")
+    click.echo(" • DIRECT MODE: for a folder with a large volume of files, it may take some time to finish.")
+    click.echo(f"{80 * '*'}\n")
+
     try:
         username, upload_key, org_subdomain, org_role, telescope_details = \
             parse_upload_watch_options(organisation, telescope, state.debug, state.verbose)
     except InvalidWatchOptionsOortCloudError:
         return
 
-    display_command_summary([folder, ], username, upload_key, org_subdomain, org_role, telescope_details)
+    display_command_summary([folder, ], username, upload_key, org_subdomain, org_role, telescope_details, zip)
 
     ok = input('\n   ----> OK? (Press Enter) ')
 
@@ -284,13 +295,15 @@ def upload(state, folder, organisation=None, telescope=None, force=False):
                             subdomain=org_subdomain or '',
                             role=org_role or '',
                             telescope=telescope_uuid,
-                            zip=False,
+                            zip=zip,
                             debug=state.debug)
 
-        walk(folder, identity, force, debug=state.debug)
+        from oort.uploader.engine.walker import walk
+
+        walk(folder, identity, bool(force), debug=state.debug)
 
 
-@main.command(help='Start watching a folder for files.')
+@main.command(help='Start watching a folder content for uploading files in batch/background mode.')
 @click.argument('folders', required=True, nargs=-1)
 @click.option('-o', '--organisation',
               required=False, nargs=1,
@@ -318,13 +331,18 @@ def watch(state, folders, organisation=None, telescope=None, zip=False):
     every new file created in the folder tree will trigger a sync + upload
     process.
     """
+    click.echo(f"\n{80 * '*'}")
+    click.echo(" • BATCH MODE: command will give the prompt back, and uploads will occur in the background.")
+    click.echo(" • BATCH MODE: use the monitor server to follow the progress (type `oort open` to open it).")
+    click.echo(f"{80 * '*'}\n")
+
     try:
         username, upload_key, org_subdomain, org_role, telescope_details = \
             parse_upload_watch_options(organisation, telescope, state.debug, state.verbose)
     except InvalidWatchOptionsOortCloudError:
         return
 
-    display_command_summary(folders, username, upload_key, org_subdomain, org_role, telescope_details)
+    display_command_summary(folders, username, upload_key, org_subdomain, org_role, telescope_details, zip)
 
     ok = input('\n   ----> OK? (Press Enter) ')
 
